﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Data;

namespace App
{
    /// <summary>
    /// Formulář pro přidání položky (Ítem)
    /// </summary>
    public partial class ItemAdd : Form
    {
        private Item item;
        private Boolean error = false;
        private List<String> errMsg = new List<string>();

        /// <summary>
        /// Konstruktor, inicializace komponenty
        /// </summary>
        public ItemAdd()
        {
            this.item = new Item(123);
            InitializeComponent();
        }

        /// <summary>
        /// Klávesové zkratky pro práci s formulářem.
        /// ENTER = uložit
        /// ESC = zavřít
        /// </summary>
        /// <param name="sender">object</param>
        /// <param name="e">KeyEventArgs</param>
        public void KeyUpEvent(object sender, KeyEventArgs e) //aby to fungovalo musí se u okna zapnout KeyPreview!!!
        {
            switch (e.KeyCode)
            {
                case Keys.Enter:
                    buttonOk.PerformClick();
                    break;

                case Keys.Escape:
                    buttonCancel.PerformClick();
                    break;

                default:
                    break;
            }
        }

        /// <summary>
        /// Metoda zkontroluje jestli nové ID nemá již nějaká jiná položka.
        /// <param name="id">Integer</param>
        /// </summary>
        private bool checkId(int id)
        {
            foreach (Item item in Core.items)
            {
                if (item.ID == id)
                {
                    MessageBox.Show("Položka s tímto ID již existuje.");
                    return false;
                }
            }
            return true;
        }

        /// <summary>
        /// Uzavře formulář bez uložení dat, klávesová zkratka ESC.
        /// </summary>
        /// <param name="sender">object</param>
        /// <param name="e">EventArgs</param>
        private void buttonCancel_Click(object sender, EventArgs e)
        {
            Close();
        }

        /// <summary>
        /// Uložení nové položky v programu. Klávesová zkratka ENTER.
        /// </summary>
        /// <param name="sender">object</param>
        /// <param name="e">EventArgs</param>
        private void buttonOk_Click(object sender, EventArgs e)
        {
            if (itemCtrl1.TextBoxId.Text != "" && checkId(int.Parse(itemCtrl1.TextBoxId.Text)))
            {
                item.ID = int.Parse(itemCtrl1.TextBoxId.Text);

                if (itemCtrl1.TextBoxDesc.Text != "")
                {
                    item.Description = itemCtrl1.TextBoxDesc.Text;
                }
                else
                {
                    error = true;
                    errMsg.Add("Popis nemůže být prázdný");
                }

                if (itemCtrl1.TextBoxQuantity.Text != "")
                {
                    item.Quantity = int.Parse(itemCtrl1.TextBoxQuantity.Text);
                }
                else
                {
                    error = true;
                    errMsg.Add("Množství nemůže být prázdné");
                }

                if (itemCtrl1.TextBoxPrice.Text != "")
                {
                    item.PricePerQ = int.Parse(itemCtrl1.TextBoxPrice.Text);
                }
                else
                {
                    error = true;
                    errMsg.Add("Cena za jednotku nemůže být prázdná");
                }

                item.Price = int.Parse(itemCtrl1.TextBoxPrice.Text) * int.Parse(itemCtrl1.TextBoxQuantity.Text);

                if (error)
                {
                    string str = "";
                    foreach (String s in errMsg)
                    {
                        str += s + "\n";
                        errMsg.Remove(s);
                    }
                    MessageBox.Show(str);
                    error = false;
                }
                else
                {
                    Core.items.Add(item);
                    Close();
                }
            }
            else
            {
                MessageBox.Show("Nesprávně zadné ID");
            }
        }

        private void ItemAdd_FormClosing(object sender, FormClosingEventArgs e)
        {
            //událost při zavírání okna
        }
    }
}
