﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

using Data;

namespace App
{
    /// <summary>
    /// Hlavní okno aplikace, na různé události volá odpovídající metody
    /// </summary>
    public partial class Main : Form
    {
        public static DataLoader loader = new DataLoader();
        public static DataSaver saver = new DataSaver();

        public Main()
        {
            InitializeComponent();
            Core.people = loader.loadPeopleFromFile();
            Core.items = loader.loadItemsFromFile();
            Core.invoices = loader.loadInvoicesFromFile();
            showPerson();
        }

        private void menuClose_Click(object sender, EventArgs e)
        {
            if (MessageBox.Show("Chcete data uložit?", "Ukončení", MessageBoxButtons.YesNo) == DialogResult.Yes)
            {
                saveData();
            }
            Close();
        }

        private void menuImportPeople_Click(object sender, EventArgs e)
        {
            BindingList<Person> imported = loader.loadPeopleFromFile("txt", false);
            if (imported != null)
            {
                Core.people = imported;
                MessageBox.Show("Soubor byl úspěšně načten.");
            }
            showPerson();
        }

        private void menuEditPeople_Click(object sender, EventArgs e)
        {
            PersonEdit editPerson = new PersonEdit(listPrimary);
            editPerson.Show();
            showPerson();
        }

        private void menuShowPeople_Click(object sender, EventArgs e)
        {
            showPerson();
        }

        private void listPrimary_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (listPrimary.SelectedItem.GetType() == typeof(Person))
            {
                showAssocToPerson(listPrimary.SelectedItem as Person);
                menuEnablator("person");
            }
            if (listPrimary.SelectedItem.GetType() == typeof(Invoice))
            {
                showAssocToInvoice(listPrimary.SelectedItem as Invoice);
                menuEnablator("invoice");
            }
            if (listPrimary.SelectedItem.GetType() == typeof(Item))
            {
                menuEnablator("item");
            }
        }

        private void menuAddPeople_Click(object sender, EventArgs e)
        {
            PersonAdd addPerson = new PersonAdd();
            addPerson.Show();
            showPerson();
        }

        private void menuDelPeople_Click(object sender, EventArgs e)
        {
            Person p = listPrimary.SelectedItem as Person;
            if (MessageBox.Show("Skutečně smazat tohoto uživatele?\n"+p.Name+" "+p.Surname, "Potvrzení akce", MessageBoxButtons.YesNo) == DialogResult.Yes)
            {
                Core.people.Remove(p);
            }
            showPerson();
        }

        private void menuShowItem_Click(object sender, EventArgs e)
        {
            showItems();
        }

        private void menuShowInvoices_Click(object sender, EventArgs e)
        {
            showInvoices();
        }

        public void showPerson()
        {
            listSecondary.Items.Clear();
            listPrimary.Items.Clear();
            foreach (Person os in Core.people)
            {
                listPrimary.Items.Add(os);
            }
            menuEnablator("nothing");
        }

        public void showInvoices()
        {
            listSecondary.Items.Clear();
            listPrimary.Items.Clear();
            foreach (Invoice inv in Core.invoices)
            {
                listPrimary.Items.Add(inv);
            }
            menuEnablator("nothing");
        }

        public void showItems()
        {
            listSecondary.Items.Clear();
            listPrimary.Items.Clear();
            foreach (Item it in Core.items)
            {
                listPrimary.Items.Add(it);
            }
            menuEnablator("nothing");
        }

        private void showAssocToPerson(Person p)
        {
            listSecondary.Items.Clear();
            foreach (Invoice inv in Core.invoices)
            {
                if (inv.Subscriber.Equals(p) || inv.Supplier.Equals(p))
                    listSecondary.Items.Add(inv);
            }
        }

        private void showAssocToInvoice(Invoice inv)
        {
            listSecondary.Items.Clear();
            foreach (Item itm in Core.items)
            {
                foreach (Item itm2 in inv.Items)
                {
                    if (itm.Equals(itm2))
                        listSecondary.Items.Add(itm2);
                }
            }
        }

        private void editWhatever(object sender, EventArgs e)
        {
            if (listPrimary.SelectedItem.GetType() == typeof(Person))
                menuEditPeople_Click(sender, e);
            else if (listPrimary.SelectedItem.GetType() == typeof(Invoice))
                menuEditInvoice_Click(sender, e);
            else if (listPrimary.SelectedItem.GetType() == typeof(Item))
                menuEditItem_Click(sender, e);
        }

        private void editWhateverSecond(object sender, EventArgs e)
        {
            /*na osobu v druhém listBoxu nikdy kliknou nemohu*/
            if (listSecondary.SelectedItem.GetType() == typeof(Invoice))
                menuEditInvoice_Click(sender, e);
            else if (listSecondary.SelectedItem.GetType() == typeof(Item))
                menuEditItem_Click(sender, e);
        }

        private void menuEditInvoice_Click(object sender, EventArgs e)
        {
            InvoiceEdit editInvoice;
            if(sender.Equals(listSecondary))
                editInvoice = new InvoiceEdit(listSecondary);
            else
                editInvoice = new InvoiceEdit(listPrimary);
            editInvoice.Show();
            showInvoices();
        }

        private void menuEnablator(string type = "all")
        {
            if (type.CompareTo("person") == 0)
            {
                menuEditPeople.Enabled = menuDelPeople.Enabled = true;
                menuEditInvoice.Enabled = menuDelInvoice.Enabled = false;
                menuEditItem.Enabled = menuDelItem.Enabled = false;
            }
            else if (type.CompareTo("invoice") == 0)
            {
                menuEditPeople.Enabled = menuDelPeople.Enabled = false;
                menuEditInvoice.Enabled = menuDelInvoice.Enabled = true;
                menuEditItem.Enabled = menuDelItem.Enabled = false;
            }
            else if (type.CompareTo("item") == 0)
            {
                menuEditPeople.Enabled = menuDelPeople.Enabled = false;
                menuEditInvoice.Enabled = menuDelInvoice.Enabled = false;
                menuEditItem.Enabled = menuDelItem.Enabled = true;
            }
            else
            {
                menuEditPeople.Enabled = menuDelPeople.Enabled = false;
                menuEditInvoice.Enabled = menuDelInvoice.Enabled = false;
                menuEditItem.Enabled = menuDelItem.Enabled = false;
            }
        }

        private void menuAddInvoice_Click(object sender, EventArgs e)
        {
            InvoiceAdd addInvoice = new InvoiceAdd();
            addInvoice.Show();
            showInvoices();
        }

        private void menuDelInvoice_Click(object sender, EventArgs e)
        {
            Invoice inv = listPrimary.SelectedItem as Invoice;
            if (MessageBox.Show("Opravdu chcete smazat tuto fakturu?", "Potvrzení akce", MessageBoxButtons.YesNo) == DialogResult.Yes)
            {
                Core.invoices.Remove(inv);
            }
            showInvoices();
        }

        private void menuAddItem_Click(object sender, EventArgs e)
        {
            ItemAdd addItem = new ItemAdd();
            addItem.Show();
            showItems();
        }

        private void menuEditItem_Click(object sender, EventArgs e)
        {
            ItemEdit editItem;
            if (sender.Equals(listSecondary))
                editItem = new ItemEdit(listSecondary);
            else
                editItem = new ItemEdit(listPrimary);
            editItem.Show();
            showItems();
        }

        private void menuDelItem_Click(object sender, EventArgs e)
        {
            Item item = listPrimary.SelectedItem as Item;
            if (MessageBox.Show("Opravdu chcete smazat tuto položku?", "Potvrzení akce", MessageBoxButtons.YesNo) == DialogResult.Yes)
            {
                Core.items.Remove(item);
            }
            showItems();
        }

        private void menuExportXml_Click(object sender, EventArgs e)
        {
            XmlExport xml = new XmlExport();
        }

        private void menuPersonXml_Click(object sender, EventArgs e)
        {
            XmlExport xml = new XmlExport("people");
        }

        private void menuInvoiceXml_Click(object sender, EventArgs e)
        {
            XmlExport xml = new XmlExport("invoices");
        }

        private void menuItemXml_Click(object sender, EventArgs e)
        {
            XmlExport xml = new XmlExport("items");
        }

        private void menuImportInvoices_Click(object sender, EventArgs e)
        {
            BindingList<Invoice> imported = loader.loadInvoicesFromFile("txt", false);
            if (imported != null)
            {
                Core.invoices = imported;
                MessageBox.Show("Soubor byl úspěšně načten.");
            }
            showInvoices();
        }

        private void menuImportItems_Click(object sender, EventArgs e)
        {
            BindingList<Item> imported = loader.loadItemsFromFile("txt", false);
            if (imported != null)
            {
                Core.items = imported;
                MessageBox.Show("Soubor byl úspěšně načten.");
            }
            showInvoices();
        }

        private void menuSave_Click(object sender, EventArgs e)
        {
            saveData();
        }

        private void saveData()
        {
            saver.savePeople();
            saver.saveInvoices();
            saver.saveItems();
        }
    }
}
