﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Data;

namespace App
{
    /// <summary>
    /// Formulář pro přidání osoby (Person)
    /// </summary>
    public partial class PersonAdd : Form
    {

        private Person p;
        private Boolean error = false;
        private List<String> errMsg = new List<string>();

        /// <summary>
        /// Konstruktor, inicializace komponenty
        /// </summary>
        public PersonAdd()
        {
            this.p = new Person(123);
            InitializeComponent();
        }

        /// <summary>
        /// Uložení nové faktury v programu. Klávesová zkratka ENTER.
        /// </summary>
        /// <param name="sender">object</param>
        /// <param name="e">EventArgs</param>
        private void personOk_Click(object sender, EventArgs e)
        {
            if (personCtrl1.TextBoxId.Text != "" && checkId(int.Parse(personCtrl1.TextBoxId.Text)))
            {
                if (personCtrl1.TextBoxName.Text != "")
                    p.Name = personCtrl1.TextBoxName.Text;
                else
                    error = true;
                    errMsg.Add("Jméno nemůže být prázdné");

                if (personCtrl1.TextBoxLastName.Text != "")
                    p.Surname = personCtrl1.TextBoxLastName.Text;
                else
                    error = true;
                    errMsg.Add("Přijmení nemůže být prázdné");
                p.CompanyId = int.Parse(personCtrl1.TextBoxId.Text);
                p.BankAccount = personCtrl1.TextBoxBank.Text;
                p.TaxId = personCtrl1.TextBoxTaxId.Text;
                p.Street = personCtrl1.TextBoxStreet.Text;
                if (personCtrl1.TextBoxStreetNr.Text != "")
                    p.NR = int.Parse(personCtrl1.TextBoxStreetNr.Text);
                if (personCtrl1.TextBoxPostCode.Text != "")
                    p.PostCode = int.Parse(personCtrl1.TextBoxPostCode.Text);
                //p.Datum = personCtrl1.DateTimePicker1.Text;

                
                if (error)
                {
                    string str = "";
                    foreach (String s in errMsg)
                    {
                        str += s + "\n";
                        errMsg.Remove(s);
                    }
                    MessageBox.Show(str);
                    error = false;
                }
                else
                {
                    Core.people.Add(p);
                    Close();
                }
            }
            else
            {
                MessageBox.Show("Nesprávně zadné IČ");
            }
        }

        /// <summary>
        /// Uzavře formulář bez uložení dat, klávesová zkratka ESC.
        /// </summary>
        /// <param name="sender">object</param>
        /// <param name="e">EventArgs</param>
        private void personCancel_Click(object sender, EventArgs e)
        {
            Close();
        }

        /// <summary>
        /// Metoda zkontroluje jestli nové ID nemá již nějaká jiná osoba.
        /// <param name="id">Integer </param>
        /// </summary>
        private bool checkId(int id)
        {
            foreach (Person person in Core.people)
            {
                if (person.CompanyId == id)
                {
                    MessageBox.Show("Osoba s tímto IČ již existuje.");
                    return false;
                }
            }
            return true;
        }

        /// <summary>
        /// Klávesové zkratky pro práci s formulářem.
        /// ENTER = uložit
        /// ESC = zavřít
        /// </summary>
        /// <param name="sender">object</param>
        /// <param name="e">KeyEventArgs</param>
        public void KeyUpEvent(object sender, KeyEventArgs e) //aby to fungovalo musí se u okna zapnout KeyPreview!!!
        {
            switch (e.KeyCode)
            {
                case Keys.Enter:
                    personOk.PerformClick();
                    break;

                case Keys.Escape:
                    personCancel.PerformClick();
                    break;

                default:
                    break;
            }
        }
    }
}
