﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Data
{
    /// <summary>
    /// Trida Item (Položka) slouží pro reprezentaci jedné položky na faktruře
    /// </summary>
    public class Item
    {

        private int id;
        //slovní popis položky
        private String description;
        //množství
        private int quantity;
        //cena za jednotku
        private int pricePerQ;
        //celková cena
        private int price;

        /// <summary>
        /// Kontruktor
        /// </summary>
        /// <param name="id">int, ID položky</param>
        public Item(int id)
        {
            this.id = id;
        }

        /// <summary>
        /// Konstruktor
        /// </summary>
        /// <param name="id">int, ID položky</param>
        /// <param name="desc">string popis</param>
        public Item(int id, String desc)
            : this(id, desc, 0, 0)
        {
        }

        /// <summary>
        /// Kontruktor - úplný
        /// </summary>
        /// <param name="id">int, ID položky</param>
        /// <param name="desc">string, popis</param>
        /// <param name="quantity">int, množství</param>
        /// <param name="pricePerQuantity">int, cena za jednotku</param>
        public Item(int id, String desc, int quantity, int pricePerQuantity)
        {
            this.id = id;
            this.description = desc;
            this.quantity = quantity;
            this.pricePerQ = pricePerQuantity;
            this.price = this.quantity * this.pricePerQ;
        }

        /// <value>
        /// ID položky
        /// </value>
        public int ID
        {
            get { return id; }
            set { id = value; }
        }

        /// <value>
        /// Slovní popis účtované služby
        /// </value>
        public String Description
        {
            get { return description; }
            set { description = value; }
        }

        /// <value>
        /// Počet jednotek služby
        /// </value>
        public int Quantity
        {
            get { return quantity; }
            set { quantity = value; }
        }

        /// <value>
        /// Cena za jednotku služby
        /// </value>
        public int PricePerQ
        {
            get { return pricePerQ; }
            set { pricePerQ = value; }
        }

        /// <value>
        /// Cena za celou službu
        /// </value>
        public int Price
        {
            get { return price; }
            set { price = value; }
        }

        //metody

        /// <summary>
        /// Informace o položce pro uložení do souboru
        /// </summary>
        /// <returns>string</returns>
        public string toSave()
        {
            return "" + id + "|" + description + "|" + quantity + "|" + pricePerQ;
        }

        /// <summary>
        /// Informace o položce pro výpis
        /// </summary>
        /// <returns>string</returns>
        public override string ToString()
        {
            return "Item: " + id + " " + description + " " + quantity + " x " + pricePerQ + " = " + price;
        }

        /// <summary>
        /// Porovná dva objekty, jestli jsou stejné
        /// </summary>
        /// <param name="obj">object</param>
        /// <returns>TRUE objekty jsou stejné, jinak FALSE</returns>
        public override bool Equals(object obj)
        {
            if (this.GetHashCode() == obj.GetHashCode())
            {
                return true;
            }
            else
            {
                return false;
            }
        }

        /// <summary>
        /// Hashcode pro porovnávání
        /// </summary>
        /// <returns></returns>
        public override int GetHashCode()
        {
            return this.id;
        }
    }
}
